---
widget: featurette
headless: true
weight: 20
title: Features
subtitle: Document _anything_ ✨
feature:
  - icon: book-open
    icon_pack: fas
    name: Project Documentation
    description: For users
  - icon: question
    icon_pack: fas
    name: Knowledge Base
    description: For teams
  - icon: list-alt
    icon_pack: fas
    name: Personal Notebook
    description: For yourself

active: false
---
